@@ -1,5 +1,11 @@
+# $Id: /mirror/gungho/lib/Gungho/Request.pm 6402 2007-04-06T17:34:44.214589Z lestrrat  $
+#
+# Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
+# All rights reserved.
+
 package Gungho::Request;
 use strict;
+use warnings;
 use base qw(HTTP::Request);
 
 1;
